@@ -13,9 +13,6 @@ from web_foundation.kernel.container import DependencyContainer
 AccessCallback = Callable[
     [AbstractDbModel | List[AbstractDbModel] | None, InputContext, Type[ModelLoader]], Coroutine[
         Any, Any, None]]
-RetrieveAccessCallback = Callable[
-    [AbstractDbModel | List[AbstractDbModel] | None, InputContext, Type[ModelLoader]], Coroutine[
-        Any, Any, AbstractDbModel | List[AbstractDbModel] | None]]
 
 
 async def exec_access(inc: InputContext,
@@ -24,7 +21,7 @@ async def exec_access(inc: InputContext,
                       fetch_fields: List[str] = None,
                       middleware: Type[ModelLoader] = ModelLoader,
                       external_callback: AccessCallback = None,
-                      retrieved_callback: RetrieveAccessCallback = None
+                      retrieved_callback: AccessCallback = None
                       ):
     """
     Access to models
@@ -98,7 +95,7 @@ async def exec_access_with_total(inc: InputContext,
                                  fetch_fields: List[str] = None,
                                  middleware: Type[ModelLoader] = ModelLoader,
                                  external_callback: AccessCallback = None,
-                                 retrieved_callback: RetrieveAccessCallback = None):
+                                 retrieved_callback: AccessCallback = None):
     """Return from read_all dict with "items" and "total" """
     result = await exec_access(inc=inc, model=model, container=container, fetch_fields=fetch_fields,
                                middleware=middleware,
