@@ -19,21 +19,33 @@ class OsFilesResource(FilesResource):
         self.root = root
         super().__init__(*args, **kwargs)
 
-    def exists(self, path: Path) -> bool:
+    async def exists(self, path: Path) -> bool: # Todo async
         return self.root.joinpath(path).exists()
 
-    def get_full_path(self, path: Path) -> Path:
+    async def get_full_path(self, path: Path) -> Path: # Todo async
         return self.root.joinpath(path)
 
     async def open(self, path: Path, *args, **kwargs) -> AiofilesContextManager:
         return open(self.root.joinpath(path), *args, **kwargs)
 
-    async def remove(self, path: Path, *args, **kwargs):
-        if path.is_dir():
+    async def remove(self, path: Path, recursive: bool = False, *args, **kwargs):
+        if recursive and path.is_dir():
             await rmtree(path, *args, **kwargs)
         else:
             await os.remove(path, *args, **kwargs)
 
+    async def replace(self, path: Path, new_path: Path, *args, **kwargs):
+        await os.replace(path, new_path, *args, **kwargs)
+
+    async def mkdir(self, path: Path, *args, **kwargs):
+        await os.mkdir(path, *args, **kwargs)
+
+    async def makedirs(self, path: Path, *args, **kwargs):
+        await os.makedirs(path, exist_ok=True)
+
+    async def rename(self, path: Path, new_name: str, *args, **kwargs):
+        await os.rename(path, path.parent.joinpath(new_name))
+
     async def list(self, path: Path, *args, **kwargs) -> Generator[Path, None, None]:
         target = self.root.joinpath(path)
         return target.iterdir()
